@@ -10,6 +10,7 @@ import os
 import warnings
 from logging import getLogger
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
+from warnings import warn
 
 import numpy as np
 import pandas as pd
@@ -290,6 +291,9 @@ class ScmDataFrame:  # pylint: disable=too-many-public-methods
         """
         Initialize.
 
+        .. deprecated:: 0.5.0
+          :class:`ScmDataFrame` will be removed in scmdata 0.6.0, it is replaced by :class:`scmdata.run.ScmRun`.
+
         Parameters
         ----------
         data: Union[ScmDataFrame, IamDataFrame, pd.DataFrame, pd.Series, np.ndarray, str]
@@ -336,6 +340,8 @@ class ScmDataFrame:  # pylint: disable=too-many-public-methods
         **kwargs:
             Additional parameters passed to :func:`pyam.core._read_file` to read files
 
+
+
         Raises
         ------
         ValueError
@@ -346,6 +352,11 @@ class ScmDataFrame:  # pylint: disable=too-many-public-methods
         TypeError
             Timeseries cannot be read from :obj:`data`
         """
+        warn(
+            "ScmDataFrame has been deprecated and will be removed in v0.6.0. Use the ScmRun class instead",
+            DeprecationWarning,
+            2,
+        )
         if columns is not None:
             (_df, _meta) = _from_ts(data, index=index, **columns)
         elif isinstance(data, ScmDataFrame):
@@ -478,6 +489,29 @@ class ScmDataFrame:  # pylint: disable=too-many-public-methods
 
         return d.T
 
+    def long_data(self, time_axis=None):
+        """
+        Return data in long form, particularly useful for plotting with seaborn
+
+        Parameters
+        ----------
+        time_axis: None
+            Not used
+
+        Returns
+        -------
+        :obj:`pd.DataFrame`
+            :obj:`pd.DataFrame` containing the data in 'long form' (i.e. one observation per row).
+        """
+        if time_axis is not None:
+            warnings.warn("Ignoring time_axis value. Use the ScmRun class instead")
+
+        out = self.timeseries().stack()
+        out.name = "value"
+        out = out.to_frame().reset_index()
+
+        return out
+
     @property
     def values(self) -> np.ndarray:
         """
@@ -1233,9 +1267,7 @@ class ScmDataFrame:  # pylint: disable=too-many-public-methods
             return ret
         return None
 
-    def relative_to_ref_period_mean(
-        self, append_str: Optional[str] = None, **kwargs: Any
-    ) -> pd.DataFrame:
+    def relative_to_ref_period_mean(self, append_str=None, **kwargs):
         """
         Return the timeseries relative to a given reference period mean.
 
@@ -1244,10 +1276,7 @@ class ScmDataFrame:  # pylint: disable=too-many-public-methods
         Parameters
         ----------
         append_str
-            String to append to the name of all the variables in the resulting DataFrame
-            to indicate that they are relevant to a given reference period. E.g. `'rel.
-            to 1961-1990'`. If None, this will be autofilled with the keys and ranges of
-            :obj:`kwargs`.
+            Deprecated
 
         **kwargs
             Arguments to pass to :func:`filter` to determine the data to be included in
@@ -1255,27 +1284,31 @@ class ScmDataFrame:  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`pd.DataFrame`
-            DataFrame containing the timeseries, adjusted to the reference period mean
+        :obj:`ScmDataFrame`
+            New object containing the timeseries, adjusted to the reference period mean.
+            The reference period year bounds are stored in the meta columns
+            ``"reference_period_start_year"`` and ``"reference_period_end_year"``.
+
+        Raises
+        ------
+        NotImplementedError
+            ``append_str`` is not ``None``
         """
+        if append_str is not None:
+            raise NotImplementedError("`append_str` is deprecated")
+
         ts = self.timeseries()
         # mypy confused by `inplace` default
-        ref_period_mean = (
-            self.filter(**kwargs).timeseries().mean(axis="columns")  # type: ignore
-        )
+        ref_data = self.filter(**kwargs)
+        ref_period_mean = ref_data.timeseries().mean(axis="columns")  # type: ignore
 
         res = ts.sub(ref_period_mean, axis="rows")
         res.reset_index(inplace=True)
 
-        if append_str is None:
-            append_str = ";".join(
-                ["{}: {} - {}".format(k, v[0], v[-1]) for k, v in kwargs.items()]
-            )
-            append_str = "(ref. period {})".format(append_str)
+        res["reference_period_start_year"] = ref_data["year"].min()
+        res["reference_period_end_year"] = ref_data["year"].max()
 
-        res["variable"] = res["variable"].apply(lambda x: "{} {}".format(x, append_str))
-
-        return res.set_index(ts.index.names)
+        return type(self)(res)
 
     def append(
         self,
